@@ -7,6 +7,9 @@ from collections import namedtuple
 from tornado import gen
 from .cortx_authenticator import CortxAuthenticator
 # from .utils import (MultiPartUploadHelper,_get_key,_get_path, _get_full_path,_get_type,_get_format,_get_type_from_key)
+from .utils import (
+    _run_sync_in_new_thread,MultiPartUploadHelper,_check_directory_exists,_check_file_exists,_get,_save,_delete,_rename,_new_untitled,_new,_copy,_create_checkpoint,_restore_checkpoint,_list_checkpoints,_delete_checkpoint
+    )
 from .utils import *
 import json 
 
@@ -58,7 +61,7 @@ class CortxJupyter(ContentsManager):
 
         @gen.coroutine
         def dir_exists_async():
-            return (yield _dir_exists(self._config(), path))
+            return (yield _check_directory_exists(self._config(), path))
 
         return _run_sync_in_new_thread(dir_exists_async)
 
@@ -66,7 +69,7 @@ class CortxJupyter(ContentsManager):
 
         @gen.coroutine
         def file_exists_async():
-            return (yield _file_exists(self._config(), path))
+            return (yield _check_file_exists(self._config(), path))
 
         return _run_sync_in_new_thread(file_exists_async)
 
