@@ -99,7 +99,7 @@ def _delete_sort_key(key):
 
 @gen.coroutine
 def _check_directory_exists(config, path):
-    return True if _is_root(path) else (yield _file_exists(config, path + FOLDER_SEPERATOR))
+    return True if _is_root(path) else (yield _check_file_exists(config, path + FOLDER_SEPERATOR))
 
 
 def _is_root(path):
@@ -109,7 +109,7 @@ def _is_root(path):
 
 
 @gen.coroutine
-def _file_exists(config, path):
+def _check_file_exists(config, path):
 
     @gen.coroutine
     def key_exists():
@@ -129,7 +129,7 @@ def _file_exists(config, path):
 
 @gen.coroutine
 def _exists(config, path):
-    return (yield _file_exists(config, path)) or (yield _check_directory_exists(config, path))
+    return (yield _check_file_exists(config, path)) or (yield _check_directory_exists(config, path))
 
 
 @gen.coroutine
